# Author:  Pablo Marti
# Copyright (C) 2006  Warp Networks S.L.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
"""
SMS related classes and utilities
"""
__version__ = "$Rev: 281 $"

# python imports
from cStringIO import StringIO
import time
# VMC imports
from _smsrecv import pdu_to_short_message
from _smssend import SMSSubmitPDU

class ShortMessage(object):
    """I represent a SMS in the system"""
    
    def __init__(self, number, text, datetime=None, where=None, index=None):
        self.number = number
        assert isinstance(text, unicode)
        self.text = text
        self.datetime = datetime
        self.where = where
        self.index = index
    
    def __str__(self):
        return self.__class__.__name__ + \
             ' : Number = %s,\nText: %s' % (self.number, self.text)
    
    def get_localised_date(self):
        return time.strftime("%c", self.datetime.timetuple())

def message_to_pdu(message):
    sms = SMSSubmitPDU(message.number, message.text)
    stream = StringIO()
    sms.serialize(stream)
    pdu_text = stream.getvalue()
    return pdu_text

def pdu_to_message(pdu):
    rawsms = pdu_to_short_message(pdu)
    
    return ShortMessage(rawsms.address.get_number(),
                           rawsms.user_data,
                           rawsms.datetime)
    